]> ruderich.org/simon Gitweb - config/dotfiles.git/blobdiff - xmonad.hs
xmonad.hs: Reorder source for layout hook.
[config/dotfiles.git] / xmonad.hs
index 598f2873d720f10f0f614be4b0ce7363bd2d6784..3be3de54af92e2732222d7820b5883cfc64495e1 100644 (file)
--- a/xmonad.hs
+++ b/xmonad.hs
@@ -1,4 +1,6 @@
--- Xmonad configuration file.
+-- XMonad configuration file.
+--
+-- Should work fine with XMonad 0.7 and above.
 
 
 import XMonad
@@ -6,6 +8,8 @@ import XMonad
 import XMonad.Layout.Reflect
 -- Necessary for avoidMaster.
 import qualified XMonad.StackSet as W
+-- Necessary for smartBorders.
+import XMonad.Layout.NoBorders
 
 
 -- Prevent new windows from spawning in the master pane. Taken from
@@ -20,26 +24,33 @@ avoidMaster = W.modify' $ \c -> case c of
 --
 -- Only use horizontal (Mirror tiled) and fullscreen layouts.
 --
--- The master pane is at the bottom of the screen (reflectVert). To make sure
--- new windows don't spawn in the master pane avoidMaster (see below) is used.
+-- The master pane is at the top of the screen. To make sure new windows don't
+-- spawn in the master pane avoidMaster (see below) is used. Borders are only
+-- drawn when the screen has more then one window (smartBorders).
 --
 -- Thanks to jrick in #xmonad on Freenode (2009-06-29 22:19) for telling me
 -- how to remove the vertical tiled layout.
-myLayoutHook = reflectVert $ Mirror tiled ||| Full
+myLayoutHook = smartBorders $ Mirror tiled ||| Full
     where
     -- Default tiling algorithm partitions the screen into two panes.
     tiled   = Tall nmaster delta ratio
     -- The default number of windows in the master pane.
     nmaster = 1
-    -- Default proportion of screen occupied by master pane.
-    ratio   = 1/2
     -- Percent of screen to increment by when resizing panes.
     delta   = 3/100
+    -- Default proportion of screen occupied by master pane.
+    ratio   = 1/2
 
--- Don't spawn new windows in the master pane (which is now at the bottom of
--- the screen). Thanks to dschoepe, aavogt and especially vav in #xmonad on
+-- Don't spawn new windows in the master pane (which is at the top of the
+-- screen). Thanks to dschoepe, aavogt and especially vav in #xmonad on
 -- Freenode (2009-06-30 02:10f).
-myManageHook = doF avoidMaster
+--
+-- Also some applications are spawned on specific workspaces. Thanks to
+-- dschoepe and ivanm in #xmonad on Freenode (2009-07-12 14:50).
+myManageHook = composeAll
+    [ className =? "Iceweasel" --> doF (W.shift "2")
+    , className =? "Wireshark" --> doF (W.shift "3")
+    ] <+> doF avoidMaster
 
 main = xmonad $ defaultConfig
     -- Use Windows key as main key so it doesn't conflict with any other key
@@ -52,4 +63,6 @@ main = xmonad $ defaultConfig
     -- Use my layout and manage hooks (see above).
     , layoutHook = myLayoutHook
     , manageHook = myManageHook
+    -- Use unicode rxvt as my terminal.
+    , terminal = "urxvt"
     }